@@ -26,7 +26,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.5"
+version = "1.2.6"
 referer_list = ["https://www.google.com/", "https://www.youtube.com/", "https://www.twitter.com/", "https://www.discord.com/", "https://www.tiktok.com/", "https://www.instagram.com/"]
 
 major = str(sys.version_info.major)
@@ -196,10 +196,6 @@ class ip:
         a = lgreen+bold+"["+clear+"+"+lgreen+bold+"]"+clear
         r01 = url.replace("https://", "http://")
         url = r01.replace("http://http://", "http://")
-        pr = requests.get("https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json").json()
-        pr_ip = pr["ip"]
-        pr_port = pr["port"]
-        proxis = pr_ip+":"+pr_port
         res=requests.get(url, stream=True, headers=headers)
         ip=res.raw._original_response.fp.raw._sock.getpeername()[0]
         res2=url + " : " + str(ip)
